==> abg_utils-6.8.8.tar.gz: lib/src/model/subscription.dart <==
import 'dart:ui';

import '../../abg_utils.dart';

class SubscriptionData{
  final String id;
  final List<StringData> text;
  final List<StringData> text2;
  final double price;
  final Color color;
  final String desc;
  final bool defaultItem;
  double scale = 1;

  SubscriptionData({this.id = "", required this.text, this.price = 0, this.desc = "", this.defaultItem = false,
    this.color = const Color(0xfff7a062), required this.text2,
  });

  Map<String, dynamic> toJson() => {
    "text": text.map((i) => i.toJson()).toList(),
    "text2": text2.map((i) => i.toJson()).toList(),
    "price": price,
    'color': color.value.toString(),
    'desc': desc,
    'defaultItem': defaultItem,
  };

  factory SubscriptionData.fromJson(String _id, Map<String, dynamic> data){
    List<StringData> _text = [];
    if (data['text'] != null)
      for (var element in List.from(data['text'])) {
        _text.add(StringData.fromJson(element));
      }
    List<StringData> _text2 = [];
    if (data['text2'] != null)
      for (var element in List.from(data['text2'])) {
        _text2.add(StringData.fromJson(element));
      }
    return SubscriptionData(
      id : _id,
      text: _text,
      text2: _text2,
      price: data["price"] != null ? toDouble(data["price"].toString()) : 0.0,
      color: (data["color"] != null) ? toColor(data["color"]) : Color(0xfff7a062),
      desc: (data["desc"] != null) ? data["desc"] : "",
      defaultItem: (data["defaultItem"] != null) ? data["defaultItem"] : "",
    );
  }
}

==> abg_utils-6.8.9.tar.gz: lib/src/model/subscription.dart <==
import 'dart:ui';

import '../../abg_utils.dart';

class SubscriptionData{
  final String id;
  final List<StringData> text;
  final List<StringData> text2;
  final double price;
  final Color color;
  final List<StringData> desc;
  final bool defaultItem;
  double scale = 1;

  SubscriptionData({this.id = "", required this.text, this.price = 0, required this.desc,
    this.defaultItem = false,
    this.color = const Color(0xfff7a062), required this.text2,
  });

  Map<String, dynamic> toJson() => {
    "text": text.map((i) => i.toJson()).toList(),
    "text2": text2.map((i) => i.toJson()).toList(),
    "price": price,
    'color': color.value.toString(),
    'desc': desc.map((i) => i.toJson()).toList(),
    'defaultItem': defaultItem,
  };

  factory SubscriptionData.fromJson(String _id, Map<String, dynamic> data){
    List<StringData> _text = [];
    if (data['text'] != null)
      for (var element in List.from(data['text'])) {
        _text.add(StringData.fromJson(element));
      }
    List<StringData> _text2 = [];
    if (data['text2'] != null)
      for (var element in List.from(data['text2'])) {
        _text2.add(StringData.fromJson(element));
      }
    List<StringData> _desc = [];
    if (data['desc'] != null)
      for (var element in List.from(data['desc'])) {
        _desc.add(StringData.fromJson(element));
      }
    return SubscriptionData(
      id : _id,
      text: _text,
      text2: _text2,
      price: data["price"] != null ? toDouble(data["price"].toString()) : 0.0,
      color: (data["color"] != null) ? toColor(data["color"]) : Color(0xfff7a062),
      desc: _desc,
      defaultItem: (data["defaultItem"] != null) ? data["defaultItem"] : "",
    );
  }
}
